==> zio-aws-apigatewayv2_2.12-5.17.104.11-sources.jar: zio/aws/apigatewayv2/model/GetTagsRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetTagsRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest = {
    import GetTagsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetTagsRequest.wrap(buildAwsValue())
}
object GetTagsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetTagsRequest =
      zio.aws.apigatewayv2.model.GetTagsRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ) extends zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ): zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-7.21.15.7-sources.jar: zio/aws/apigatewayv2/model/GetTagsRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetTagsRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest = {
    import GetTagsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetTagsRequest.wrap(buildAwsValue())
}
object GetTagsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetTagsRequest =
      zio.aws.apigatewayv2.model.GetTagsRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ) extends zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetTagsRequest
  ): zio.aws.apigatewayv2.model.GetTagsRequest.ReadOnly = new Wrapper(impl)
}
